@@ -8,7 +8,7 @@ import numpy as np
 
 from numcodecs.bz2 import BZ2
 from numcodecs.tests.common import check_encode_decode, check_config, \
-    check_repr
+    check_repr, check_backwards_compatibility
 
 
 codecs = [
@@ -43,3 +43,7 @@ def test_config():
 
 def test_repr():
     check_repr("BZ2(level=3)")
+
+
+def test_backwards_compatibility():
+    check_backwards_compatibility(BZ2.codec_id, arrays, codecs)
