@@ -4,11 +4,12 @@ import itertools
 
 
 import numpy as np
-
+from nose.tools import eq_ as eq
 
 from numcodecs.zlib import Zlib
-from numcodecs.tests.common import check_encode_decode, check_config, \
-    check_repr
+from numcodecs.registry import get_codec
+from numcodecs.tests.common import check_encode_decode, check_config, check_repr, \
+    check_backwards_compatibility
 
 
 codecs = [
@@ -45,3 +46,13 @@ def test_config():
 
 def test_repr():
     check_repr("Zlib(level=3)")
+
+
+def test_alias():
+    config = dict(id='gzip', level=1)
+    codec = get_codec(config)
+    eq(Zlib(1), codec)
+
+
+def test_backwards_compatibility():
+    check_backwards_compatibility(Zlib.codec_id, arrays, codecs)
